==> ideaIC-173.3531.6-sources.jar: com/android/tools/idea/gradle/structure/configurables/android/dependencies/treeview/GoToModuleAction.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.configurables.android.dependencies.treeview;

import com.android.tools.idea.gradle.structure.configurables.PsContext;
import com.intellij.openapi.actionSystem.ActionManager;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.project.DumbAwareAction;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

import static com.intellij.openapi.actionSystem.IdeActions.ACTION_GOTO_DECLARATION;

public class GoToModuleAction extends DumbAwareAction {
  @NotNull private final String myModuleName;
  @NotNull private final PsContext myContext;
  @NotNull private final Object myInvoker;

  public GoToModuleAction(@NotNull String moduleName, @NotNull PsContext context, @NotNull JComponent invoker) {
    super(String.format("Go to module '%1$s'", moduleName));
    myModuleName = moduleName;
    myContext = context;
    myInvoker = invoker;
    registerCustomShortcutSet(ActionManager.getInstance().getAction(ACTION_GOTO_DECLARATION).getShortcutSet(), invoker);
  }

  @Override
  public void actionPerformed(AnActionEvent e) {
    myContext.setSelectedModule(myModuleName, myInvoker);
  }
}

==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/gradle/structure/configurables/android/dependencies/treeview/GoToModuleAction.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.configurables.android.dependencies.treeview;

import com.android.tools.idea.gradle.structure.configurables.PsContext;
import com.intellij.openapi.actionSystem.ActionManager;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.project.DumbAwareAction;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

import static com.intellij.openapi.actionSystem.IdeActions.ACTION_GOTO_DECLARATION;

public class GoToModuleAction extends DumbAwareAction {
  @NotNull private final String myModuleName;
  @NotNull private final PsContext myContext;
  @NotNull private final Object myInvoker;

  public GoToModuleAction(@NotNull String moduleName, @NotNull PsContext context, @NotNull JComponent invoker) {
    super(String.format("Go to module '%1$s'", moduleName));
    myModuleName = moduleName;
    myContext = context;
    myInvoker = invoker;
    registerCustomShortcutSet(ActionManager.getInstance().getAction(ACTION_GOTO_DECLARATION).getShortcutSet(), invoker);
  }

  @Override
  public void actionPerformed(@NotNull AnActionEvent e) {
    myContext.setSelectedModule(myModuleName, myInvoker);
  }
}
